local RUF = LibStub("AceAddon-3.0"):GetAddon("RUF")
local L = LibStub("AceLocale-3.0"):GetLocale("RUF")
local _, ns = ...
local oUF = ns.oUF
local cfg = RUF_cfg
local tags = oUF.Tags.Methods or oUF.Tags
local events = oUF.TagEvents or oUF.Tags.Events

local function Short(value,format)
	if type(value) == "number" then
		local fmt
		if value >= 1000000000 or value <= -1000000000 then
			fmt = "%.1fB"
			value = value / 1000000000
		elseif value >= 10000000 or value <= -10000000 then
			fmt = "%.1fM"
			value = value / 1000000
		elseif value >= 1000000 or value <= -1000000 then
			fmt = "%.2fM"
			value = value / 1000000
		elseif value >= 100000 or value <= -100000 then
			fmt = "%.0fK"
			value = value / 1000
		elseif value >= 10000 or value <= -10000 then
			fmt = "%.1fK"
			value = value / 1000
		else
			fmt = "%d"
			value = math.floor(value + 0.5)
		end
		if format then
			return fmt:format(value)
		end
		return fmt, value
	else
		local fmt_a, fmt_b
		local a, b = value:match("^(%d+)/(%d+)$")
		if a then
			a, b = tonumber(a), tonumber(b)
			if a >= 1000000000 or a <= -1000000000 then
				fmt_a = "%.1fB"
				a = a / 1000000000
			elseif a >= 10000000 or a <= -10000000 then
				fmt_a = "%.1fM"
				a = a / 1000000
			elseif a >= 1000000 or a <= -1000000 then
				fmt_a = "%.2fM"
				a = a / 1000000
			elseif a >= 100000 or a <= -100000 then
				fmt_a = "%.0fK"
				a = a / 1000
			elseif a >= 10000 or a <= -10000 then
				fmt_a = "%.1fK"
				a = a / 1000
			end
			if b >= 1000000000 or b <= -1000000000 then
				fmt_b = "%.1fB"
				b = b / 1000000000
			elseif b >= 10000000 or b <= -10000000 then
				fmt_b = "%.1fM"
				b = b / 1000000
			elseif b >= 1000000 or b <= -1000000 then
				fmt_b = "%.2fM"
				b = b / 1000000
			elseif b >= 100000 or b <= -100000 then
				fmt_b = "%.0fK"
				b = b / 1000
			elseif b >= 10000 or b <= -10000 then
				fmt_b = "%.1fK"
				b = b / 1000
			end
			local fmt = ("%s/%s"):format(fmt_a, fmt_b)
			if format then
				return fmt:format(a, b)
			end
			return fmt, a, b
		else
			return value
		end
	end
end

local function Round(number, digits)
	local mantissa = 10^(digits or 0)
	local norm = number * mantissa + 0.5
	local norm_floor = math.floor(norm)
	if norm == norm_floor and (norm_floor % 2) == 1 then
		return (norm_floor - 1) / mantissa
	end
	return norm_floor / mantissa
end

local function Percent(x, y)
	if y ~= 0 then
		return Round(x / y * 100, 1)
	end
	return 0
end

-- Unit smart level
tags['Raeli:Level'] = function(unit)
	local l = UnitLevel(unit)
	local c = GetQuestDifficultyColor(l)  
	if l <= 0 then l = "??" end  
	if l ~= UnitLevel("player") then
		return string.format('|cff%02x%02x%02x%s|r',c.r*255,c.g*255,c.b*255,l)
	else
		return ''
	end
  end
  events['Raeli:Level'] = 'UNIT_LEVEL PLAYER_LEVEL_UP UNIT_CLASSIFICATION_CHANGED'

-- Uppercase Name
-- Limits NPC names to 18 characters.
tags['Raeli:UpperName'] = function(unit)
	local name = string.upper(UnitName(unit))
	if UnitIsPlayer(unit) then
		local class = select(2,UnitClass(unit))
		local cr,cg,cb = unpack(RUF.db.profile.Colors.ClassColors[class])
		return string.format('|cff%02x%02x%02x%s|r',cr*255,cg*255,cb*255,name)
	elseif UnitPlayerControlled(unit) and not UnitCanAttack("target","player") then -- If the unit is an allied pet then show as blue.
		local rr,rg,rb = unpack(RUF.db.profile.Colors.ReactionColors[10])
		return string.format('|cff%02x%02x%02x%s|r',rr*255,rg*255,rb*255,name)
	else
		local rr,rg,rb = unpack(RUF.db.profile.Colors.ReactionColors[UnitReaction(unit, 'player')])
		return string.format('|cff%02x%02x%02x%s|r',rr*255,rg*255,rb*255,string.sub(name,1,18))
	end
end
events['Raeli:UpperName'] = 'UNIT_NAME_UPDATE UNIT_ENTERING_VEHICLE UNIT_EXITING_VEHICLE'

tags['Raeli:AFKDND'] = function(unit)
	if UnitIsAFK(unit) then
		return string.format('|cffFFFFFF[AFK]|r')
	end
	if UnitIsDND(unit) then
		return string.format('|cffFFFFFF[DND]|r')
	end
end
events['Raeli:AFKDND'] = 'PLAYER_FLAGS_CHANGED'


-- Health
-- Class Coloured if Player, Reaction Coloured if NPC, Gradient Coloured if below 100%
tags['Raeli:FullHealth'] = function(unit)
	local cur, max = UnitHealth(unit), UnitHealthMax(unit)
	if(UnitIsDead(unit)) then
		return 'Dead'
	elseif(UnitIsGhost(unit)) then
		return 'Ghost'
	elseif(not UnitIsConnected(unit)) then
		return 'Offline'
	end
	if cur == max then
		if UnitIsPlayer(unit) then
			local class = select(2,UnitClass(unit))
			local cr,cg,cb = unpack(RUF.db.profile.Colors.ClassColors[class])
			return string.format('|cff%02x%02x%02x%s|r',cr*255,cg*255,cb*255,Short(cur,true))
		elseif UnitPlayerControlled(unit) and not UnitCanAttack("target","player") then -- If the unit is an allied pet then show as blue.
			local rr,rg,rb = unpack(RUF.db.profile.Colors.ReactionColors[10])
			return string.format('|cff%02x%02x%02x%s|r',rr*255,rg*255,rb*255,Short(cur,true))
		else
			local rr,rg,rb = unpack(RUF.db.profile.Colors.ReactionColors[UnitReaction(unit, 'player')])
			return string.format('|cff%02x%02x%02x%s|r',rr*255,rg*255,rb*255,Short(cur,true))
		end
	elseif cur < max and cur > 0 then
		local gr, gg, gb = ColorGradient(cur, max, unpack(RUF.db.profile.Colors.GradientColors))	
		return string.format('|cff%02x%02x%02x%s%s%s%%|r',gr*255,gg*255,gb*255,Short(cur,true), " - ",Percent(cur,max))
	end
end
events['Raeli:FullHealth'] = 'UNIT_HEALTH UNIT_CONNECTION'

-- Power value
-- Percentage shown if below 100%, hidden if 0
tags['Raeli:Power'] = function(unit)
	local cur, max = UnitPower(unit), UnitPowerMax(unit)
	local pType,pToken,altr,altg,altb = UnitPowerType(unit)
	--if (altr ~= nil) or (altg ~= nil) or (altb ~= nil) then
	--	local pr,pg,pb = altr or 0,altg or 0,altb or 0
	--else
		local pr,pg,pb = unpack(RUF.db.profile.Colors.PowerColors[pType])
	--end
	if max == 0 then
		return ''
	elseif cur == max then
		return string.format('|cff%02x%02x%02x%s|r',pr*255,pg*255,pb*255,Short(cur,true))
	elseif cur < max and cur > 0 then
		return string.format('|cff%02x%02x%02x%s%s%s%%|r',pr*255,pg*255,pb*255,Short(cur,true), " - ",Percent(cur,max))
	else
		return ''
	end

end
events['Raeli:Power'] = 'UNIT_POWER'



--[[
if RUF.db.profile.unit[unit].Bars.Power == 0 and element.__owner.Power:IsShown() then -- Always Hidden on this unit.
	element.__owner.Power:Hide()
	element.__owner.Power.bg:Hide()
elseif RUF.db.profile.unit[unit].Bars.Power == 1 then -- Hidden at 0
	if cur < 1 and element.__owner.Power:IsShown() then
		element.__owner.Power:Hide()
		element.__owner.Power.bg:Hide()
	end
	if cur > 0 and not element.__owner.Power:IsShown() then 
		element.__owner.Power:Show()
		element.__owner.Power.bg:Show() 
	end
elseif 	RUF.db.profile.unit[unit].Bars.Power == 2 and not element.__owner.Power:IsShown() then		
	element.__owner.Power:Show()
	element.__owner.Power.bg:Show() 	
end]]--
