------------------------------------------------
---- Raeli's Unit Frames Options Module ----
------------------------------------------------

local RUF = LibStub("AceAddon-3.0"):GetAddon("RUF")
local L = LibStub("AceLocale-3.0"):GetLocale("RUF")
local RUF_O = RUF:NewModule("RUF_Options")
local LSM = LibStub("LibSharedMedia-3.0")
local _, ns = ...
local oUF = ns.oUF
local DefaultOptions = RUF_cfg
local cfg
------------------------
---- Global Options ----
------------------------
local units = {
	oUF_RUF_Player,
	oUF_RUF_Pet,
	oUF_RUF_Target,
	oUF_RUF_TargetTarget,
	oUF_RUF_Focus,
	--oUF_RUF_FocusTarget,
	oUF_RUF_Boss1,
	oUF_RUF_Boss2,
	oUF_RUF_Boss3,
	oUF_RUF_Boss4,
	oUF_RUF_Boss5,
	oUF_RUF_Arena1,
	oUF_RUF_Arena2,
	oUF_RUF_Arena3,
	oUF_RUF_Arena4,
	oUF_RUF_Arena5,
	oUF_RUF_RaidUnitButton1,
	oUF_RUF_RaidUnitButton2,
	oUF_RUF_RaidUnitButton3,
	oUF_RUF_RaidUnitButton4,
	oUF_RUF_RaidUnitButton5,
}

local function UpdateUnitSettings()
	RUF.db.profile.unit.boss1 = RUF.db.profile.unit.boss
	RUF.db.profile.unit.boss2 = RUF.db.profile.unit.boss
	RUF.db.profile.unit.boss3 = RUF.db.profile.unit.boss
	RUF.db.profile.unit.boss4 = RUF.db.profile.unit.boss
	RUF.db.profile.unit.boss5 = RUF.db.profile.unit.boss

	RUF.db.profile.unit.arena1 = RUF.db.profile.unit.arena
	RUF.db.profile.unit.arena2 = RUF.db.profile.unit.arena
	RUF.db.profile.unit.arena3 = RUF.db.profile.unit.arena
	RUF.db.profile.unit.arena4 = RUF.db.profile.unit.arena
	RUF.db.profile.unit.arena5 = RUF.db.profile.unit.arena

	RUF.db.profile.unit.RaidUnitButton1 = RUF.db.profile.unit.party
	RUF.db.profile.unit.RaidUnitButton2 = RUF.db.profile.unit.party
	RUF.db.profile.unit.RaidUnitButton3 = RUF.db.profile.unit.party
	RUF.db.profile.unit.RaidUnitButton4 = RUF.db.profile.unit.party
	RUF.db.profile.unit.RaidUnitButton5 = RUF.db.profile.unit.party
end


local _, PlayerClass = UnitClass('player')
local ClassPowerID, ClassPowerType, ClassPowerCharges, RequireSpec, RequireSpell, ClassVisibility


do -- Register Class Bar Variable Values
	if(PlayerClass == 'MONK') then
		ClassPowerID = 12
		ClassPowerType = "CHI"
		RequireSpec = SPEC_MONK_WINDWALKER
	elseif(PlayerClass == 'PALADIN') then
		ClassPowerID = 9
		ClassPowerType = "HOLY_POWER"
		RequireSpec = SPEC_PALADIN_RETRIBUTION
	elseif(PlayerClass == 'WARLOCK') then
		ClassPowerID = 7
		ClassPowerType = "SOUL_SHARDS"
	elseif(PlayerClass == 'ROGUE' or PlayerClass == 'DRUID') then
		ClassPowerID = 4
		ClassPowerType = 'COMBO_POINTS'
		if(PlayerClass == 'DRUID') then
			RequireSpell = 5221 -- Shred
		end
	elseif(PlayerClass == 'MAGE') then
		ClassPowerID = 16
		ClassPowerType = 'ARCANE_CHARGES'
		RequireSpec = SPEC_MAGE_ARCANE
	end
end

local function UpdateFrames()
	UpdateUnitSettings()
	for i = 1,#units do
		units[i].Health:ForceUpdate()
		units[i].Health:ForceUpdate()
		units[i].Power:ForceUpdate()
		units[i].Power:ForceUpdate()
	end
end

local classbars = {
	[1] = oUF_RUF_Player_Class1,
	[2] = oUF_RUF_Player_Class2,
	[3] = oUF_RUF_Player_Class3,
	[4] = oUF_RUF_Player_Class4,
	[5] = oUF_RUF_Player_Class5,
	[6] = oUF_RUF_Player_Class6,
}

local function UpdateClassBar()
	-- if spec / spell isn't true, hide, if it is, show.
	if (ClassPowerID) then -- If we're a class that should show a class bar
		local UnitPowerMaxAmount = UnitPowerMax("player", ClassPowerID)
		if(not RequireSpec or RequireSpec == GetSpecialization()) then -- If the class requires a specific spec, and if so, if we are that spec.
			if(not RequireSpell or IsPlayerSpell(RequireSpell)) then -- If the class requires a specific spell, druid cat form.
				local pr,pg,pb = unpack(RUF.db.profile.Colors.PowerColors[ClassPowerID])
				local UnitPowerMaxAmount = UnitPowerMax("player", ClassPowerID)
				local multiplier
				--self.ClassPower.bg:SetStatusBarColor(pr*0.75,pg*0.75,pb*0.75,0.5)
				for index = 1, UnitPowerMaxAmount do
					multiplier = index
					if UnitPowerMaxAmount == 4 then
						multiplier = index +1
					end
					local curr = (pr*((((multiplier+10)*6.6667)/100)))
					local curg = (pg*((((multiplier+10)*6.6667)/100)))
					local curb = (pb*((((multiplier+10)*6.6667)/100)))
					classbars[index]:SetStatusBarColor(curr,curg,curb)
				end
			end
		end
	end
end



local Options = {
	type = "group",
	name = function(info)
		return "RUF [|c5500DBBDRaeli's Unit Frames|r]" .. (GetAddOnMetadata("RUF", "Version") or "") .. " " .. (GetAddOnMetadata("RUF", "X-Curse-Packaged-Version") or "") .. "|r"
	end,	
	order = 0,
	childGroups = "tab",
	args = {
		MainGroup = {
			name = L["Global Options"],
			desc = L["These settings affect all frames."],
			type = "group",
			order = 0,
			args = {
				Category_Header_Health = {
					type = "header",
					name = L["Health Bar Settings"],
					order = 0,
				},
				Category_Health_BarTexture = {
					type = "select",
					name = L["Health Texture"],
					desc = L["Set the Health bar texture."],
					width = "normal",
					values = LSM:HashTable("statusbar"),
					dialogControl = "LSM30_Statusbar",
					order = 0.1,
					get = function(info)
						return RUF.db.profile.Texture.Health
					end,
					set = function(info, value)
						RUF.db.profile.Texture.Health = value
						for i = 1,#units do
							units[i].Health:SetStatusBarTexture(LSM:Fetch("statusbar", RUF.db.profile.Texture.Health))
						end
					end,
				},
				Category_Health_Spacer_1 = {
					type = "description",
					name = "  ",
					width = "full",
					order = 0.5,
				},	
				Category_Health_TappingColor = {
					order = 1.0,
					type = "color",
					name = L["Tapped Color"],
					get = function(info)
						return RUF.db.profile.Colors.MiscColors.Tapping[1],RUF.db.profile.Colors.MiscColors.Tapping[2],RUF.db.profile.Colors.MiscColors.Tapping[3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.MiscColors.Tapping = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Health_DisconnectedColor = {
					order = 1.1,
					type = "color",
					name = L["Disconnected Color"],
					get = function(info)
						return RUF.db.profile.Colors.MiscColors.Disconnected[1],RUF.db.profile.Colors.MiscColors.Disconnected[2],RUF.db.profile.Colors.MiscColors.Disconnected[3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.MiscColors.Disconnected = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Health_HealthColor = {
					order = 1.2,
					type = "color",
					name = L["Health Color"],
					get = function(info)
						return RUF.db.profile.Colors.Health.HealthColor[1],RUF.db.profile.Colors.Health.HealthColor[2],RUF.db.profile.Colors.Health.HealthColor[3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.Health.HealthColor = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Health_Spacer_2 = {
					type = "description",
					name = "  ",
					width = "full",
					order = 1.5,
				},				   
				Category_Health_ClassColor = {-- Priority: Tapping, Disconnected, Class, ClassNPC, ClassPet, Reaction, Smooth, Health
					order = 2.0,
					type = "toggle",
					name = L["Colour bar by class"],
					get = function(info)
						return RUF.db.profile.Colors.Health.colorClass
					end,
					set = function(info, value)
						RUF.db.profile.Colors.Health.colorClass = value
						UpdateFrames()
					end,
				},
				Category_Health_ReactionColor = {
					order = 2.1,
					type = "toggle",
					name = L["Colour bar by reaction"],
					get = function(info)
						return RUF.db.profile.Colors.Health.colorReaction
					end,
					set = function(info, value)
						RUF.db.profile.Colors.Health.colorReaction = value
						UpdateFrames()
					end,
				},
				Category_Health_PercentageColor = {
					order = 2.2,
					type = "toggle",
					name = L["Colour bar by percentage"],
					get = function(info)
						return RUF.db.profile.Colors.Health.colorSmooth
					end,
					set = function(info, value)
						RUF.db.profile.Colors.Health.colorSmooth = value
						UpdateFrames()
					end,
				},
				Category_Health_PercentageColor_100 = {
					order = 3.0,
					type = "color",
					name = L["Full Health"],
					desc = L["Health Color at 100% Health"],
					hidden =  function() return not RUF.db.profile.Colors.Health.colorSmooth end,
					get = function(info)
						return RUF.db.profile.Colors.Health.HealthBarGradient[7],RUF.db.profile.Colors.Health.HealthBarGradient[8],RUF.db.profile.Colors.Health.HealthBarGradient[9]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.Health.HealthBarGradient[7] = r
						RUF.db.profile.Colors.Health.HealthBarGradient[8] = g
						RUF.db.profile.Colors.Health.HealthBarGradient[9] = b
						UpdateFrames()
					end,
				},
				Category_Health_PercentageColor_50 = {
					order = 3.1,
					type = "color",
					name = L["Half Health"],
					desc = L["Health Color at 50% Health"],
					hidden =  function() return not RUF.db.profile.Colors.Health.colorSmooth end,
					get = function(info)
						return RUF.db.profile.Colors.Health.HealthBarGradient[4],RUF.db.profile.Colors.Health.HealthBarGradient[5],RUF.db.profile.Colors.Health.HealthBarGradient[6]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.Health.HealthBarGradient[4] = r
						RUF.db.profile.Colors.Health.HealthBarGradient[5] = g
						RUF.db.profile.Colors.Health.HealthBarGradient[6] = b
						UpdateFrames()
					end,
				},
				Category_Colors_Health_PercentageColor_0 = {
					order = 3.2,
					type = "color",
					name = L["Zero Health"],
					desc = L["Health Color at 0% Health"],
					hidden =  function() return not RUF.db.profile.Colors.Health.colorSmooth end,
					get = function(info)
						return RUF.db.profile.Colors.Health.HealthBarGradient[1],RUF.db.profile.Colors.Health.HealthBarGradient[2],RUF.db.profile.Colors.Health.HealthBarGradient[3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.Health.HealthBarGradient[1] = r
						RUF.db.profile.Colors.Health.HealthBarGradient[2] = g
						RUF.db.profile.Colors.Health.HealthBarGradient[3] = b
						UpdateFrames()
					end,
				},


				Category_Header_Power = {
					type = "header",
					name = "Power Bar Settings",
					order = 10,
				},
				Category_Power_BarTexture = {
					type = "select",
					name = L["Power Texture"],
					desc = L["Set the Power bar texture."],
					values = LSM:HashTable("statusbar"),
					dialogControl = "LSM30_Statusbar",
					order = 10.1,
					get = function(info)
						return RUF.db.profile.Texture.Power
					end,
					set = function(info, value)
						RUF.db.profile.Texture.Power = value
						for i = 1,#units do
							units[i].Power:SetStatusBarTexture(LSM:Fetch("statusbar", RUF.db.profile.Texture.Power))
						end
					end,
				},
				Category_Power_Spacer_1 = {
					type = "description",
					name = "  ",
					width = "half",
					order = 10.2,
				},	
				Category_Power_ClassBarTexture = {
					type = "select",
					name = L["Class Bar Texture"],
					desc = L["Set the Class bar texture."],
					values = LSM:HashTable("statusbar"),
					dialogControl = "LSM30_Statusbar",
					order = 10.3,
					get = function(info)
						return RUF.db.profile.Texture.Class
					end,
					set = function(info, value)
						RUF.db.profile.Texture.Class = value
						local UnitPowerMaxAmount = UnitPowerMax("player", ClassPowerID)
						oUF_RUF_Player_Class1:SetStatusBarTexture(LSM:Fetch("statusbar", RUF.db.profile.Texture.Class))
						oUF_RUF_Player_Class2:SetStatusBarTexture(LSM:Fetch("statusbar", RUF.db.profile.Texture.Class))
						oUF_RUF_Player_Class3:SetStatusBarTexture(LSM:Fetch("statusbar", RUF.db.profile.Texture.Class))
						oUF_RUF_Player_Class4:SetStatusBarTexture(LSM:Fetch("statusbar", RUF.db.profile.Texture.Class))
						if UnitPowerMaxAmount >= 5 then
							oUF_RUF_Player_Class5:SetStatusBarTexture(LSM:Fetch("statusbar", RUF.db.profile.Texture.Class))
						end
						if UnitPowerMaxAmount >= 6 then
							oUF_RUF_Player_Class6:SetStatusBarTexture(LSM:Fetch("statusbar", RUF.db.profile.Texture.Class))
						end						
					end,
				},
				Category_Power_Spacer_2 = {
					type = "description",
					name = "  ",
					width = "full",
					order = 10.5,
				},	
				Category_Colors_Power_Mana = {
					order = 11.0,
					type = "color",
					name = _G['MANA'] or MANA,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[0][1],RUF.db.profile.Colors.PowerColors[0][2],RUF.db.profile.Colors.PowerColors[0][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[0] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Rage = {
					order = 11.1,
					type = "color",
					name = _G['RAGE'] or RAGE,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[1][1],RUF.db.profile.Colors.PowerColors[1][2],RUF.db.profile.Colors.PowerColors[1][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[1] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Focus = {
					order = 11.2,
					type = "color",
					name = _G['FOCUS'] or FOCUS,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[2][1],RUF.db.profile.Colors.PowerColors[2][2],RUF.db.profile.Colors.PowerColors[2][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[2] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Energy = {
					order = 11.3,
					type = "color",
					name = _G['ENERGY'] or ENERGY,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[3][1],RUF.db.profile.Colors.PowerColors[3][2],RUF.db.profile.Colors.PowerColors[3][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[3] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Combo = {
					order = 11.4,
					type = "color",
					name = _G['COMBO_POINTS'] or COMBO_POINTS,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[4][1],RUF.db.profile.Colors.PowerColors[4][2],RUF.db.profile.Colors.PowerColors[4][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[4] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Runes = {
					order = 11.5,
					type = "color",
					name = _G['RUNES'] or RUNES,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[5][1],RUF.db.profile.Colors.PowerColors[5][2],RUF.db.profile.Colors.PowerColors[5][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[5] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Runic = {
					order = 11.6,
					type = "color",
					name = _G['RUNIC_POWER'] or RUNIC_POWER,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[6][1],RUF.db.profile.Colors.PowerColors[6][2],RUF.db.profile.Colors.PowerColors[6][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[6] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Shards = {
					order = 11.7,
					type = "color",
					name = _G['SOUL_SHARDS'] or SOUL_SHARDS,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[7][1],RUF.db.profile.Colors.PowerColors[7][2],RUF.db.profile.Colors.PowerColors[7][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[7] = {r,g,b}
						UpdateFrames()
						UpdateClassBar()
					end,
				},
				Category_Colors_Power_Astral = {
					order = 11.8,
					type = "color",
					name = _G['LUNAR_POWER'] or LUNAR_POWER,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[8][1],RUF.db.profile.Colors.PowerColors[8][2],RUF.db.profile.Colors.PowerColors[8][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[8] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Holy = {
					order = 11.9,
					type = "color",
					name = _G['HOLY_POWER'] or HOLY_POWER,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[9][1],RUF.db.profile.Colors.PowerColors[9][2],RUF.db.profile.Colors.PowerColors[9][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[9] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Maelstrom = {
					order = 11.11,
					type = "color",
					name = _G['MAELSTROM'] or MAELSTROM,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[11][1],RUF.db.profile.Colors.PowerColors[11][2],RUF.db.profile.Colors.PowerColors[11][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[11] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Chi = {
					order = 11.12,
					type = "color",
					name = _G['CHI'] or CHI,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[12][1],RUF.db.profile.Colors.PowerColors[12][2],RUF.db.profile.Colors.PowerColors[12][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[12] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Insanity = {
					order = 11.13,
					type = "color",
					name = _G['INSANITY'] or INSANITY,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[13][1],RUF.db.profile.Colors.PowerColors[13][2],RUF.db.profile.Colors.PowerColors[13][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[13] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Arcane = {
					order = 11.16,
					type = "color",
					name = _G['ARCANE_CHARGES'] or ARCANE_CHARGES,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[16][1],RUF.db.profile.Colors.PowerColors[16][2],RUF.db.profile.Colors.PowerColors[16][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[16] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Fury = {
					order = 11.17,
					type = "color",
					name = _G['FURY'] or FURY,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[17][1],RUF.db.profile.Colors.PowerColors[17][2],RUF.db.profile.Colors.PowerColors[17][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[17] = {r,g,b}
						UpdateFrames()
					end,
				},
				Category_Colors_Power_Pain = {
					order = 11.18,
					type = "color",
					name = _G['PAIN'] or PAIN,
					get = function(info)
						return RUF.db.profile.Colors.PowerColors[18][1],RUF.db.profile.Colors.PowerColors[18][2],RUF.db.profile.Colors.PowerColors[18][3]
					end,
					set = function(info,r,g,b)
						RUF.db.profile.Colors.PowerColors[18] = {r,g,b}
						UpdateFrames()
					end,
				},

			},
		},

	}, -- Options Args
}

-----------------------
---- Ace functions ----
-----------------------
function RUF_O:OnInitialize()
	self.db = LibStub("AceDB-3.0"):New("RUFDB", DefaultOptions) -- Setup Saved Variables

	
	
	-- Profile Management --
	self.db.RegisterCallback(self, "OnProfileChanged", "RefreshConfig")
	self.db.RegisterCallback(self, "OnProfileCopied", "RefreshConfig")
	self.db.RegisterCallback(self, "OnProfileReset", "RefreshConfig")
	------------------------
	db = self.db.profile
	-- Register Various Options
	LibStub("AceConfig-3.0"):RegisterOptionsTable("RUF", Options) -- Register Options
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("RUF", "RUF") -- Add options to Blizzard interface
	
	local Profiles = LibStub("AceDBOptions-3.0"):GetOptionsTable(self.db) -- Add profile management to Blizzard interface
	
	LibStub("AceConfig-3.0"):RegisterOptionsTable("RUF_Profiles", Profiles) -- Register Options
	self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("RUF_Profiles", "Profiles", "RUF") -- Add options to Blizzard interface
	
	--LibStub("AceConfig-3.0"):RegisterOptionsTable("RUF_FAQ", FAQ) -- Register Options
	--self.optionsFrame = LibStub("AceConfigDialog-3.0"):AddToBlizOptions("RUF_FAQ", "Help", "RUF") -- Add options to Blizzard interface
	
	-- Add dual-spec support
	local LibDualSpec = LibStub('LibDualSpec-1.0')
	LibDualSpec:EnhanceDatabase(self.db, "RUF")
	LibDualSpec:EnhanceOptions(Profiles, self.db)
	
	InterfaceAddOnsList_Update()
end
function RUF_O:RefreshConfig(event, database, newProfileKey) -- Seems to be working fine.
	RUF.db = database -- Setup Saved Variables
	--[[if RUF.db.profile.Modules.Reminders == true then
		local loaded, reason = LoadAddOn("RUF_Reminders")
		if not loaded then
			if reason == "DISABLED" or reason == "INTERFACE_VERSION" then
				ChatFrame1:AddMessage("|cFFFF75B3RUF:|r Reminders " .. L.OptionsDisabled)
			elseif reason == "MISSING" or reason == "CORRUPT" then
				ChatFrame1:AddMessage("|cFFFF75B3RUF:|r Reminders " .. L.OptionsMissing)
			end
		else
			RUF:EnableModule("Reminders")
		end
	else
		if LoadAddOn("RUF_Reminders") == 1 then
			RUF:DisableModule("Reminders")
		end
	end]]--
end
